@@ -131,7 +131,7 @@ def _logging_adjust() -> None:
 
 def _get_sentry_integrations() -> List[object]:
     """Get integrations for Sentry based on installed packages."""
-    integrations = []
+    integrations = []  # type: List[Any]
     try:
         import flask  # noqa
     except ImportError:
@@ -336,7 +336,7 @@ def init_logging(
             raise
 
         if environment is None:
-            root_logger.warning(
+            root_logger.error(
                 "No Sentry environment configured: it is recommended to provide Sentry environment "
                 "to split reported exceptions based on different deployments when running in a cluster"
             )
