@@ -18,6 +18,7 @@
 """Handling OpenShift and Kubernetes objects across project."""
 
 import os
+import datetime
 import logging
 import requests
 import typing
@@ -397,7 +398,7 @@ class OpenShift:
     ) -> Dict[str, Any]:
         """Get status from a task/node in a workflow."""
         pod_id = self.get_workflow_pod_name(node_name, workflow_id, namespace)
-        return self.get_pod_status(pod_id, namespace)
+        return self.get_pod_status_report(pod_id, namespace)
 
     def get_build(self, build_id: str, namespace: str) -> Dict[str, Any]:
         """Get a build in the given namespace."""
@@ -762,6 +763,43 @@ class OpenShift:
         job_spec["metadata"]["generateName"] = item["metadata"]["name"] + "-"
         return job_spec
 
+    def schedule_graph_schema_update(
+        self, job_id: Optional[str] = None, namespace: Optional[str] = None
+    ) -> str:
+        """Schedule graph schema update job in infra namespace by default."""
+        if namespace is None:
+            if not self.infra_namespace:
+                raise ConfigurationError(
+                    "No infra namespace configured to run graph-schema-update job"
+                )
+
+            namespace = self.infra_namespace
+
+        template = self._get_template(
+            "template=graph-schema-update-job", namespace=namespace
+        )
+
+        job_id = job_id or self.generate_id("graph-update-schema")
+        self.set_template_parameters(
+            template,
+            THOTH_SCHEMA_UPDATE_JOB_ID=job_id,
+        )
+
+        template = self.oc_process(namespace, template)
+
+        graph_update_schema_template = template["objects"][0]
+
+        response = self.ocp_client.resources.get(
+            api_version=graph_update_schema_template["apiVersion"],
+            kind=graph_update_schema_template["kind"],
+        ).create(body=graph_update_schema_template, namespace=namespace)
+
+        _LOGGER.debug("OpenShift response for creating a pod: %r", response.to_dict())
+
+        name: str = response["metadata"]["name"]
+
+        return name
+
     def schedule_graph_refresh(self, namespace: Optional[str] = None) -> str:
         """Schedule graph refresh job in frontend namespace by default."""
         if namespace is None:
@@ -820,6 +858,13 @@ class OpenShift:
             "memory"
         ]
 
+        template_parameters["THOTH_SEND_MESSAGES"] = str(
+            int(specification["send_messages"])
+        )
+        template_parameters["THOTH_FORCE_SYNC"] = str(
+            int(specification.get("force_sync", False))
+        )
+
         workflow_parameters = self._assign_workflow_parameters_for_ceph()
         workflow_parameters["dockerfile"] = dockerfile
         # Propagate raw specification to be placed on Ceph, not to submit escaped specification.
@@ -956,6 +1001,7 @@ class OpenShift:
         registry_password: Optional[str] = None,
         verify_tls: bool = True,
         debug: bool = False,
+        graph_sync: bool = False,
         job_id: Optional[str] = None,
     ) -> Optional[str]:
         """Schedule package extract workflow."""
@@ -969,12 +1015,13 @@ class OpenShift:
                 "Unknown environment type %r, has to be runtime or buildtime"
             )
 
+        job_id = job_id or self.generate_id("package-extract")
         template_parameters = {
             "THOTH_LOG_PACKAGE_EXTRACT": "DEBUG" if debug else "INFO",
             "THOTH_ANALYZED_IMAGE": image,
             "THOTH_ANALYZER_NO_TLS_VERIFY": int(not verify_tls),
-            "THOTH_PACKAGE_EXTRACT_JOB_ID": job_id
-            or self.generate_id("package-extract"),
+            "THOTH_PACKAGE_EXTRACT_JOB_ID": job_id,
+            "THOTH_SYNC_PACKAGE_EXTRACT": int(graph_sync),
             "THOTH_DOCUMENT_ID": job_id,
             "THOTH_PACKAGE_EXTRACT_METADATA": json.dumps(
                 {
@@ -1037,28 +1084,21 @@ class OpenShift:
         prefix: Optional[str] = None, identifier: Optional[str] = None
     ) -> str:
         """Generate an identifier."""
-        # A very first method used 'generatedName' in ImageStream configuration,
-        # but it looks like there is a bug in OpenShift as it did not generated any
-        # name and failed with regexp issues (that were not related to the
-        # generateName configuration).
+        suffix = f"-{datetime.datetime.now():%y%m%d%H%M%S}-{random.getrandbits(64):08x}"
         if prefix and identifier:
-            return ("%s-%s-" + "%08x") % (prefix, identifier, random.getrandbits(128))
+            return f"{prefix}-{identifier}{suffix}"
 
         if prefix:
-            return prefix + "-%08x" % random.getrandbits(128)
+            return f"{prefix}{suffix}"
 
-        return "-%08x" % random.getrandbits(128)
+        return suffix
 
     def schedule_dependency_monkey(
         self,
-        requirements: Dict[str, Any],
-        context: Dict[str, Any],
         *,
-        pipeline: Optional[Dict[str, Any]] = None,
         predictor: Optional[str] = None,
         predictor_config: Optional[Dict[str, Any]] = None,
         stack_output: Optional[str] = None,
-        runtime_environment: Optional[Dict[Any, Any]] = None,
         seed: Optional[int] = None,
         dry_run: bool = False,
         decision: Optional[str] = None,
@@ -1068,24 +1108,18 @@ class OpenShift:
         limit_latest_versions: Optional[int] = None,
     ) -> Optional[str]:
         """Schedule a dependency monkey run."""
-        if not self.middletier_namespace:
+        if not self.amun_inspection_namespace:
             raise ConfigurationError(
-                "Unable to schedule dependency monkey without middletier namespace being set"
+                "Unable to schedule dependency monkey without amun inspection namespace being set"
             )
 
         job_id = job_id or self.generate_id("dependency-monkey")
         template_parameters = {
-            "THOTH_ADVISER_REQUIREMENTS": json.dumps(requirements).replace("\n", "\\n"),
-            "THOTH_ADVISER_RUNTIME_ENVIRONMENT": None
-            if runtime_environment is None
-            else json.dumps(runtime_environment),
-            "THOTH_AMUN_CONTEXT": json.dumps(context).replace("\n", "\\n"),
             "THOTH_DEPENDENCY_MONKEY_STACK_OUTPUT": stack_output or "-",
             "THOTH_DEPENDENCY_MONKEY_DRY_RUN": int(bool(dry_run)),
             "THOTH_LOG_ADVISER": "DEBUG" if debug else "INFO",
             "THOTH_DEPENDENCY_MONKEY_JOB_ID": job_id,
             "THOTH_DOCUMENT_ID": job_id,
-            "THOTH_ADVISER_PIPELINE": json.dumps(pipeline) if pipeline else "{}",
             "THOTH_ADVISER_PREDICTOR": predictor or "AUTO",
             "THOTH_ADVISER_PREDICTOR_CONFIG": json.dumps(predictor_config)
             if predictor_config
@@ -1136,6 +1170,7 @@ class OpenShift:
         environment_type: Optional[str] = None,
         origin: Optional[str] = None,
         debug: bool = False,
+        is_external: bool = True,
         job_id: Optional[str] = None,
     ) -> Optional[str]:
         """Schedule a build analysis workflow."""
@@ -1202,6 +1237,17 @@ class OpenShift:
             "THOTH_BUILD_ANALYSIS_ORIGIN": origin,
             "THOTH_BUILD_ANALYSIS_LOG": "DEBUG" if debug else "INFO",
             "THOTH_BUILD_ANALYSIS_JOB_ID": job_id,
+            "THOTH_BUILD_ANALYSIS_METADATA": json.dumps(
+                {
+                    "origin": origin,
+                    "environment_type": environment_type,
+                    "base_image_analysis_id": base_image_analysis_id,
+                    "output_image_analysis_id": output_image_analysis_id,
+                    "buildlog_document_id": buildlog_document_id,
+                    "build_analysis_job_id": job_id,
+                    "is_external": is_external,
+                }
+            ),
         }
 
         workflow_parameters = self._assign_workflow_parameters_for_ceph()
@@ -1276,14 +1322,11 @@ class OpenShift:
 
     def schedule_adviser(
         self,
-        application_stack: Dict[Any, Any],
         recommendation_type: str,
         *,
         count: Optional[int] = None,
         limit: Optional[int] = None,
         predictor_config: Optional[Dict[str, Any]] = None,
-        runtime_environment: Optional[Dict[Any, Any]] = None,
-        library_usage: Optional[Dict[Any, Any]] = None,
         origin: Optional[str] = None,
         dev: bool = False,
         debug: bool = False,
@@ -1317,47 +1360,32 @@ class OpenShift:
         )
 
         adviser_id = job_id or self.generate_id("adviser")
-        template_parameters = {}
-
-        if application_stack.get("requirements_lock"):
-            template_parameters[
-                "THOTH_ADVISER_REQUIREMENTS_LOCKED"
-            ] = application_stack["requirements_lock"]
-        template_parameters["THOTH_ADVISER_JOB_ID"] = adviser_id
-        template_parameters["THOTH_ADVISER_DEV"] = "1" if dev else "0"
-        template_parameters["THOTH_ADVISER_REQUIREMENTS"] = application_stack[
-            "requirements"
-        ]
-        template_parameters["THOTH_ADVISER_LIBRARY_USAGE"] = json.dumps(library_usage)
-        template_parameters["THOTH_LOG_ADVISER"] = "DEBUG" if debug else "INFO"
-        template_parameters[
-            "THOTH_ADVISER_REQUIREMENTS_FORMAT"
-        ] = application_stack.get("requirements_format", "pipenv")
-        template_parameters["THOTH_ADVISER_RECOMMENDATION_TYPE"] = recommendation_type
-        template_parameters["THOTH_ADVISER_RUNTIME_ENVIRONMENT"] = json.dumps(
-            runtime_environment
-        )
-        template_parameters["THOTH_ADVISER_PREDICTOR_CONFIG"] = (
-            json.dumps(predictor_config) if predictor_config else "{}"
-        )
-
-        template_parameters["THOTH_ADVISER_METADATA"] = json.dumps(
-            {
-                "github_event_type": github_event_type,
-                "github_check_run_id": github_check_run_id,
-                "github_installation_id": github_installation_id,
-                "github_base_repo_url": github_base_repo_url,
-                "origin": origin,
-                "re_run_adviser_id": re_run_adviser_id,
-                "source_type": source_type if source_type is not None else None,
-            }
-        )
+        template_parameters = {
+            "THOTH_ADVISER_JOB_ID": adviser_id,
+            "THOTH_ADVISER_DEV": "1" if dev else "0",
+            "THOTH_LOG_ADVISER": "DEBUG" if debug else "INFO",
+            "THOTH_ADVISER_RECOMMENDATION_TYPE": recommendation_type,
+            "THOTH_ADVISER_PREDICTOR_CONFIG": (
+                json.dumps(predictor_config) if predictor_config else "{}"
+            ),
+            "THOTH_ADVISER_METADATA": json.dumps(
+                {
+                    "github_event_type": github_event_type,
+                    "github_check_run_id": github_check_run_id,
+                    "github_installation_id": github_installation_id,
+                    "github_base_repo_url": github_base_repo_url,
+                    "origin": origin,
+                    "re_run_adviser_id": re_run_adviser_id,
+                    "source_type": source_type if source_type is not None else None,
+                }
+            ),
+        }
 
         if limit is not None:
-            template_parameters["THOTH_ADVISER_LIMIT"] = limit
+            template_parameters["THOTH_ADVISER_LIMIT"] = str(limit)
 
         if count is not None:
-            template_parameters["THOTH_ADVISER_COUNT"] = count
+            template_parameters["THOTH_ADVISER_COUNT"] = str(count)
 
         workflow_parameters = self._assign_workflow_parameters_for_ceph()
 
@@ -1383,7 +1411,6 @@ class OpenShift:
 
     def schedule_provenance_checker(
         self,
-        application_stack: Dict[Any, Any],
         *,
         origin: Optional[str] = None,
         whitelisted_sources: Optional[List[str]] = None,
@@ -1398,13 +1425,7 @@ class OpenShift:
 
         job_id = job_id or self.generate_id("provenance-checker")
 
-        requirements = application_stack.pop("requirements").replace("\n", "\\n")
-        requirements_locked = application_stack.pop("requirements_lock").replace(
-            "\n", "\\n"
-        )
         template_parameters = {
-            "THOTH_ADVISER_REQUIREMENTS": requirements,
-            "THOTH_ADVISER_REQUIREMENTS_LOCKED": requirements_locked,
             "THOTH_ADVISER_METADATA": json.dumps({"origin": origin}),
             "THOTH_WHITELISTED_SOURCES": ",".join(whitelisted_sources or []),
             "THOTH_LOG_ADVISER": "DEBUG" if debug else "INFO",
